import 'package:flutter/material.dart';
import 'package:mobile_ui/mobile_ui.dart';

class AppBarBase extends StatelessWidget implements PreferredSizeWidget {
  final String title;
  final Widget titleWidget;
  final Widget leading;
  final List<Widget> actions;
  final double elevation;
  final bool centerTitle;
  final TabBar tabBar;
  final PreferredSizeWidget bottom;
  final String icon;
  final List<Color> gradientColors;

  AppBarBase({
    this.title,
    this.leading,
    this.actions,
    this.elevation,
    this.centerTitle,
    this.tabBar,
    this.bottom,
    this.icon,
    this.titleWidget,
    this.gradientColors,
  })  : assert(tabBar == null || bottom == null),
        preferredSize = Size.fromHeight(kToolbarHeight +
            (bottom?.preferredSize?.height ?? 0.0) +
            (tabBar?.preferredSize?.height ?? 0.0));

  Widget _buildBaseTitleText(ThemeData theme) {
    return Text(
      title,
      style: theme.textTheme.headline6,
    );
  }

  Widget _buildTitle(ThemeData theme) {
    var title =
    titleWidget != null ? titleWidget : _buildBaseTitleText(theme);
    if (icon != null) {
      return Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Image.asset(
            icon,
            width: 35,
            height: 35,
            fit: BoxFit.contain,
          ),
          SizedBox(
            width: uiSpacing(2),
          ),
          title
        ],
      );
    }
    return title;
  }

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);
    return AppBar(
        leading: leading,
        actions: actions,
        elevation: 0,
        centerTitle: false,
        toolbarHeight: 40,
        flexibleSpace: Container(
          decoration: BoxDecoration(
            gradient: LinearGradient(
                colors: gradientColors,
                begin: const FractionalOffset(0.0, 1.0),
                end: const FractionalOffset(0.8, 0.0),
                stops: [0.0, 1.0],
                tileMode: TileMode.clamp),
          ),
        ),
        titleSpacing: uiSpacing(1),
        title: _buildTitle(theme),
        bottom: bottom ?? tabBar);
  }

  @override
  final Size preferredSize;
}
